==> blazy-8.x-2.17-rc1.tar.gz: blazy/src/Cache/BlazyCache.php <==
<?php

namespace Drupal\blazy\Cache;

use Drupal\Core\Cache\Cache;
use Drupal\blazy\Blazy;

/**
 * Provides common cache utility static methods.
 */
class BlazyCache {

  /**
   * Return the available lightboxes, to be cached to avoid disk lookups.
   */
  public static function lightboxes($root): array {
    $lightboxes = [];
    if (function_exists('colorbox_theme')) {
      $lightboxes[] = 'colorbox';
    }

    // @todo remove deprecated unmaintained photobox.
    // Most lightboxes are unmantained, only supports mostly used, or robust.
    $paths = [
      'photobox' => 'photobox/photobox/jquery.photobox.js',
      'mfp' => 'magnific-popup/dist/jquery.magnific-popup.min.js',
    ];

    foreach ($paths as $key => $path) {
      if (is_file($root . '/libraries/' . $path)) {
        $lightboxes[] = $key;
      }
    }
    return $lightboxes;
  }

  /**
   * Return the cache metadata common for all blazy-related modules.
   */
  public static function metadata(array $build = []): array {
    $manager  = Blazy::service('blazy.manager');
    $settings = Blazy::toHashtag($build) ?: $build;

    // @todo renove after sub-modules, including some fallback settings.
    Blazy::verify($settings);

    $blazies   = $settings['blazies'];
    $namespace = $blazies->get('namespace', 'blazy');
    $count     = $blazies->get('count', count($settings));
    $max_age   = $manager->config('cache.page.max_age', 'system.performance');
    $max_age   = empty($settings['cache']) ? $max_age : $settings['cache'];
    $id        = Blazy::getHtmlId($namespace . $count);
    $id        = $blazies->get('css.id', $id);

    // Put them into cxahe.
    $cache             = [];
    $suffixes[]        = $count;
    $cache['tags']     = Cache::buildTags($namespace . ':' . $id, $suffixes, '.');
    $cache['contexts'] = ['languages', 'url.site'];
    $cache['max-age']  = $max_age;
    $cache['keys']     = $blazies->get('cache.metadata.keys', [$id]);

    if ($tags = $blazies->get('cache.metadata.tags', [])) {
      $cache['tags'] = Cache::mergeTags($cache['tags'], $tags);
    }

    return $cache;
  }

}

==> blazy-8.x-2.23.tar.gz: blazy/src/Cache/BlazyCache.php <==
<?php

namespace Drupal\blazy\Cache;

use Drupal\blazy\internals\Internals;
use Drupal\Core\Cache\Cache;

/**
 * Provides common cache utility static methods.
 *
 * @internal
 *   This is an internal part of the Blazy system and should only be used by
 *   blazy-related code in Blazy module.
 *
 * @todo remove for \Drupal\blazy\Asset\Libraries methods at 3.x.
 */
class BlazyCache {

  /**
   * Return the available lightboxes, to be cached to avoid disk lookups.
   *
   * @todo remove for \Drupal\blazy\Asset\Libraries::getLightboxes() at 3.x.
   */
  public static function lightboxes($root): array {
    $lightboxes = ['flybox'];
    if (function_exists('colorbox_theme')) {
      $lightboxes[] = 'colorbox';
    }

    // @todo remove deprecated unmaintained photobox.
    // Most lightboxes are unmantained, only supports mostly used, or robust.
    $paths = [
      'photobox' => 'photobox/photobox/jquery.photobox.js',
      'mfp' => 'magnific-popup/dist/jquery.magnific-popup.min.js',
    ];

    foreach ($paths as $key => $path) {
      if (is_file($root . '/libraries/' . $path)) {
        $lightboxes[] = $key;
      }
    }
    return $lightboxes;
  }

  /**
   * Return the cache metadata common for all blazy-related modules.
   *
   * @todo remove for \Drupal\blazy\Asset\Libraries::getCacheMetadata() at 3.x.
   */
  public static function metadata(array $build = []): array {
    $manager   = Internals::service('blazy.manager');
    $settings  = Internals::toHashtag($build) ?: $build;
    $blazies   = Internals::verify($settings);
    $namespace = $blazies->get('namespace', 'blazy');
    $count     = $blazies->total() ?: $blazies->get('count', count($settings));
    $max_age   = $manager->config('cache.page.max_age', 'system.performance');
    $max_age   = empty($settings['cache']) ? $max_age : $settings['cache'];
    $id        = Internals::getHtmlId($namespace . $count);
    $id        = $blazies->get('css.id', $id);
    $id        = substr(md5($id), 0, 11);

    // Put them into cxahe.
    $cache             = [];
    $suffixes[]        = $count;
    $cache['tags']     = Cache::buildTags($namespace . ':' . $id, $suffixes, '.');
    $cache['contexts'] = ['languages', 'url.site'];
    $cache['max-age']  = $max_age;
    $cache['keys']     = $blazies->get('cache.metadata.keys', [$id]);

    if ($tags = $blazies->get('cache.metadata.tags', [])) {
      $cache['tags'] = Cache::mergeTags($cache['tags'], $tags);
    }

    return $cache;
  }

}
